Webmention Rocks!

# Discovery Test #19

This post returns one HTTP Link header with multiple values separated by a comma. This ensures your code correcly parses the HTTP headers.
Published: Friday April 15, 2016 8:27am +02:00

### Reacji

The emoji below show Reacji responses, created by people posting a comment linking to this post with an `in-reply-to` property, whose text is a single emoji character.

### Likes

The profile icons below are the author photos from people who have posted a "like" post on their site, where their post links to this post with the `like-of` property.

### Reposts

The profile icons below are the author photos from people who have posted a "repost" of this post on their site, where their post links to this post with the `repost-of` property.

### Bookmarks

The profile icons below are the author photos from people who have posted a bookmark of this post on their site, where their post links to this post with the `bookmark-of` property.

### Comments

The comments below are replies to this post, and marked up their link to the post with the `in-reply-to` property.

### Mentions

The mentions below linked to this post, but did not include this post's URL as an `in-reply-to` property.

- Mike Taylor bear.im

  ### Checking Indieweb Code

  Saturday, September 2, 2017 8:09pm +00:00